==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface AppsV1beta1DeploymentFluent<A extends AppsV1beta1DeploymentFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> withNewMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public AppsV1beta1DeploymentFluent.MetadataNested<A> editMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> editOrNewMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1DeploymentSpec getSpec();
    public AppsV1beta1DeploymentSpec buildSpec();
    public A withSpec(AppsV1beta1DeploymentSpec spec);
    public Boolean hasSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> withNewSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> withNewSpecLike(AppsV1beta1DeploymentSpec item);
    public AppsV1beta1DeploymentFluent.SpecNested<A> editSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> editOrNewSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> editOrNewSpecLike(AppsV1beta1DeploymentSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1DeploymentStatus getStatus();
    public AppsV1beta1DeploymentStatus buildStatus();
    public A withStatus(AppsV1beta1DeploymentStatus status);
    public Boolean hasStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> withNewStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> withNewStatusLike(AppsV1beta1DeploymentStatus item);
    public AppsV1beta1DeploymentFluent.StatusNested<A> editStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> editOrNewStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> editOrNewStatusLike(AppsV1beta1DeploymentStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<AppsV1beta1DeploymentFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1DeploymentSpecFluent<AppsV1beta1DeploymentFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1DeploymentStatusFluent<AppsV1beta1DeploymentFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/AppsV1beta1DeploymentFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface AppsV1beta1DeploymentFluent<A extends AppsV1beta1DeploymentFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ObjectMeta getMetadata();
    public V1ObjectMeta buildMetadata();
    public A withMetadata(V1ObjectMeta metadata);
    public Boolean hasMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> withNewMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> withNewMetadataLike(V1ObjectMeta item);
    public AppsV1beta1DeploymentFluent.MetadataNested<A> editMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> editOrNewMetadata();
    public AppsV1beta1DeploymentFluent.MetadataNested<A> editOrNewMetadataLike(V1ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1DeploymentSpec getSpec();
    public AppsV1beta1DeploymentSpec buildSpec();
    public A withSpec(AppsV1beta1DeploymentSpec spec);
    public Boolean hasSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> withNewSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> withNewSpecLike(AppsV1beta1DeploymentSpec item);
    public AppsV1beta1DeploymentFluent.SpecNested<A> editSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> editOrNewSpec();
    public AppsV1beta1DeploymentFluent.SpecNested<A> editOrNewSpecLike(AppsV1beta1DeploymentSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public AppsV1beta1DeploymentStatus getStatus();
    public AppsV1beta1DeploymentStatus buildStatus();
    public A withStatus(AppsV1beta1DeploymentStatus status);
    public Boolean hasStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> withNewStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> withNewStatusLike(AppsV1beta1DeploymentStatus item);
    public AppsV1beta1DeploymentFluent.StatusNested<A> editStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> editOrNewStatus();
    public AppsV1beta1DeploymentFluent.StatusNested<A> editOrNewStatusLike(AppsV1beta1DeploymentStatus item);

    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ObjectMetaFluent<AppsV1beta1DeploymentFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface SpecNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1DeploymentSpecFluent<AppsV1beta1DeploymentFluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface StatusNested<N> extends io.kubernetes.client.fluent.Nested<N>,AppsV1beta1DeploymentStatusFluent<AppsV1beta1DeploymentFluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}
